@@ -489,14 +489,15 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        if hasattr(form.instance,'_is_saved') and form.instance._is_saved():
+        if form.instance.accessory is not None:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
                                                                  fk_name='parent', form=DataTransform, extra=1
                                                                  )
             form.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=form.instance,
                 data=form.data if form.is_bound else None,
-                files=form.files if form.is_bound else None
+                files=form.files if form.is_bound else None,
+                initial=[{'parent': form.instance}]
             )
 
 
